#
# spec file for package rakkess
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           rakkess
Version:        0.5.1
Release:        1.7
Summary:        Utility to show an access matrix for k8s server resources
License:        Apache-2.0
Group:          System/Management
URL:            https://github.com/corneliusweig/rakkess
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  golang(API) >= 1.15
ExcludeArch:    s390
ExcludeArch:    %{ix86}

%description
rakkess lists access rights for the current user and all server resources
on a provided kubernetes cluster.

%prep
%setup -qa1

%build
# use vendor directory and build as position independent executeable
sed -i -e 's|go build -race|go build -mod vendor -buildmode=pie|g' Makefile
%ifarch %arm
export GOARCH=arm
%endif
%ifarch aarch64
export GOARCH=arm64
%endif
%ifarch s390x ppc64le riscv64
export GOARCH=%{_arch}
%endif
%ifarch s390x ppc64le
export CGO_ENABLED=0
%endif
PLATFORMS=linux make dev VERSION=%{version}

%install
# Install the binary.
mkdir -p %{buildroot}%{_bindir}/
install -m 0755 rakkess %{buildroot}%{_bindir}/rakkess

%files
%license LICENSE
%doc doc/*
%{_bindir}/rakkess

%changelog
* Mon Nov 21 2022 kastl@b1-systems.de
- Update to version 0.5.1:
  * Drop prealloc linter
  * Bump k8s.io/klog/v2 from 2.30.0 to 2.80.1 (#166)
  * Fix extra lines in output (issue #156) (#158)
  * Bump k8s.io/klog/v2 from 2.20.0 to 2.30.0 (#155)
  * Bump k8s.io/klog/v2 from 2.9.0 to 2.20.0 (#154)
  * Bump cobra to v1.2.1 (#153)
  * Include arm64-darwin assets in fileset for release
  * Increase timeout for linter
  * Create tag v0.5.0
  * Bump codecov to v2 (#151)
* Tue Mar 29 2022 Andreas Schwab <schwab@suse.de>
- Set GOARCH on riscv64
* Wed Jan  5 2022 kastl@b1-systems.de
- Update to version 0.5.0:
  * Include arm64-darwin assets in fileset for release
  * Increase timeout for linter
  * Create tag v0.5.0
  * Fix some code findings
  * Remove obsolete test case
  * Move diff command behind a flag in root cmd
  * Bump codecov to v2 (#151)
  * Add new `diff` subcommand to compare access rules
  * Rename some symbols
  * Decouple rendering from result type(s)
  * Add abstraction for the output matrix
  * Move MatrixPrinter interface
  * Simplify and remove unnecessary types
  * Switch to builtin cobra completion implementation (#148)
  * Update dependencies (#143)
  * Switch from logrus to k8s.io/klog/v2 (#147)
  * Upgrade to GitHub-native Dependabot (#144)
  * Produce binary for darwin-arm64 (#142)
* Mon Mar  8 2021 alexandre.vicenzi@suse.com
- Update to version 0.4.7:
  * Fix Makefile
  * Create tag v0.4.7
  * Upgrade dependencies (#125)
  * Remove UPX postprocessing for Darwin builds (#124)
  * Create tag v0.4.6
  * Update dependencies k8s -> 0.19.4 (#105)
  * Bump golangci-lint to 1.31.0 (#94)
  * Bump github.com/spf13/cobra from 1.0.0 to 1.1.0 (#93)
  * Bump k8s dependencies from 0.18.8 to 0.19.2 (#91)
  * Create tag v0.4.5
* Thu Feb 27 2020 Kasimir _ <kasimir_@outlook.de>
- Fix building on %%arm architectures
* Tue Feb 18 2020 kukuk@suse.de
- Update to version 0.4.4
  - Upstream release script fixes
* Mon Feb  3 2020 kukuk@suse.de
- Update to version 0.4.3
  - Changes in build process
  - bug fixes
- Refresh vendor.tar.xz
* Thu Aug  1 2019 kukuk@suse.de
- Update to version 0.4.1
  - Update kubernetes dependencies to 1.15
  - Allow arbitrary verbs in the resource subcommand #32
* Thu Jul 25 2019 kukuk@suse.de
- Remove golang-packaging, does more harm than helps
  (e.g. bsc#1132101)
* Tue May 28 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in descriptions.
* Thu May 23 2019 Thorsten Kukuk <kukuk@suse.com>
- Fix building on non amd64 architectures
* Thu May 23 2019 Thorsten Kukuk <kukuk@suse.com>
- Initial version
